@@ -2,7 +2,9 @@ import datetime
 
 import pytest
 
-from pydbm import DbmModel, exceptions
+from pydbm import DbmModel
+from pydbm import contstant as C
+from pydbm import exceptions
 from pydbm.models import meta
 from pydbm.models.fields import AutoField
 
@@ -20,13 +22,15 @@ def test_config():
 
 
 def test_get_config():
-    config = meta.Meta.get_config("User", {})
+    config = meta.Meta.get_config(meta.Meta, "User", {})
 
     assert config.table_name == "users"
     assert config.unique_together == ()
 
     config = meta.Meta.get_config(
-        "User", {meta.CLASS_CONFIG_NAME: meta.Config(table_name="users", unique_together=("email", "username"))}
+        meta.Meta,
+        "User",
+        {C.CLASS_CONFIG_NAME: meta.Config(table_name="users", unique_together=("email", "username"))}
     )
 
     assert config.table_name == "users"
@@ -42,13 +46,14 @@ def test_meta():
 
     assert user.email == "hakancelikdev@gmail.com"
     assert user.username == "hakancelikdev"
-    assert user.pk == "7caae990504a6f4c4c8f436a3d8d009f"
+    assert user.id == "7caae990504a6f4c4c8f436a3d8d009f"
     assert user.required_fields == ["email", "username"]
     assert isinstance(user.not_required_fields[0], AutoField)
-    assert user.not_required_fields[0].public_name == "pk"
+    assert user.not_required_fields[0].public_name == "id"
     assert user.objects.table_name == "users"
     assert not hasattr(user, "__dict__")
-    assert user.__slots__ == ("_email", "_pk", "_username", "database")
+    assert user.__slots__ == ("_email", "_id", "_username", "database")
+    assert user._config.unique_together == ("email", "username")
 
 
 def test_meta_config():
@@ -61,10 +66,11 @@ def test_meta_config():
             unique_together = ("email", "username")
 
     user = User(email="hakancelikdev@gmail.com", username="hakancelikdev")
-    assert user.pk == "7caae990504a6f4c4c8f436a3d8d009f"
+    assert user.id == "7caae990504a6f4c4c8f436a3d8d009f"
     assert isinstance(user.not_required_fields[0], AutoField)
-    assert user.not_required_fields[0].public_name == "pk"
+    assert user.not_required_fields[0].public_name == "id"
     assert user.objects.table_name == "user_table"
+    assert user._config.unique_together == ("email", "username")
 
 
 def test_meta_is_required_error():
